@@ -1,31 +1,35 @@
 package v1alpha3
 
 import (
+	"bytes"
 	"encoding/json"
 	"fmt"
+	"io"
 	"io/ioutil"
 	"path/filepath"
 	"sort"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
-	"gopkg.in/yaml.v2"
+	"gopkg.in/yaml.v3"
 
 	"github.com/mbrt/gmailctl/cmd/gmailctl-config-migrate/v1alpha2"
 	"github.com/mbrt/gmailctl/internal/engine/config/v1alpha3"
 )
 
-func read(path string) []byte {
+func read(path string) io.Reader {
 	b, err := ioutil.ReadFile(path)
 	if err != nil {
 		panic(err)
 	}
-	return b
+	return bytes.NewBuffer(b)
 }
 
 func parseV2(t *testing.T, path string) v1alpha2.Config {
 	var res v1alpha2.Config
-	if err := yaml.UnmarshalStrict(read(path), &res); err != nil {
+	dec := yaml.NewDecoder(read(path))
+	dec.KnownFields(true)
+	if err := dec.Decode(&res); err != nil {
 		t.Fatal(err)
 	}
 	return res
@@ -33,7 +37,8 @@ func parseV2(t *testing.T, path string) v1alpha2.Config {
 
 func parseV3(t *testing.T, path string) v1alpha3.Config {
 	var res v1alpha3.Config
-	if err := json.Unmarshal(read(path), &res); err != nil {
+	dec := json.NewDecoder(read(path))
+	if err := dec.Decode(&res); err != nil {
 		t.Fatal(err)
 	}
 	return res
@@ -67,7 +72,7 @@ func TestConvert(t *testing.T) {
 			v3cfg := parseV3(t, v3files[i])
 
 			got, err := Import(v2cfg)
-			assert.Nil(t, err)
+			assert.NoError(t, err)
 			assert.Equal(t, dump(t, v3cfg), dump(t, got))
 		})
 	}
